@@ -28,6 +28,7 @@ class State(QObject):
         if self._value != new_value or force:
             old_value = self._value
             self._value = new_value
+            log.debug('{} changed: {!r} -> {!r}'.format(self.objectName(), old_value, new_value))
             self.changed.emit(self._value)
             self.changed2.emit(self._value, old_value)
 
@@ -94,10 +95,11 @@ class PathState(State):
         return v.strip('/')
 
 
-def mpd_cmd(method=None, ignore_conn=False, fallback=None):
+def mpd_cmd(method=None, *, ignore_conn=False, fallback=None, refresh=True):
     if method is None:
         def decorator(method):
-            return mpd_cmd(method, ignore_conn, fallback)
+            return mpd_cmd(method, ignore_conn=ignore_conn, fallback=fallback,
+                    refresh=refresh)
         return decorator
     @functools.wraps(method)
     def wrapper(self, *args, **kwargs):
@@ -107,7 +109,8 @@ def mpd_cmd(method=None, ignore_conn=False, fallback=None):
                 ret = method(self, *args, **kwargs)
             except (mpd.MPDError, OSError) as e:
                 self.handle_error(e)
-        self.update_state()
+        if refresh:
+            self.refresh()
         return ret
     return wrapper
 
@@ -120,13 +123,17 @@ def not_callable(*args):
     raise TypeError("Not callable")
 
 
-class MPDCommandList:
-    def __init__(self, conn):
-        self.conn = conn
-    def __enter__(self):
-        self.conn.command_list_ok_begin()
-    def __exit__(self, *exc):
-        self.conn.command_list_end()
+def mpd_cmdlist_context_manager(connection):
+    class MPDCommandList:
+        conn = connection
+
+        def __enter__(self):
+            self.conn.command_list_ok_begin()
+            return self
+
+        def __exit__(self, *exc):
+            self.retval = self.conn.command_list_end()
+    return MPDCommandList
 
 
 class Connection:
@@ -168,10 +175,10 @@ class ProperConnection(Connection):
         super().__init__(main)
         self.main = main
         self.conn = mpd.MPDClient()
-        self.mpd_cmdlist = MPDCommandList(self.conn)
+        self.mpd_cmdlist = mpd_cmdlist_context_manager(self.conn)
         State.create(self, 'state', 'disconnect', not_callable)
 
-    def update_state(self):
+    def refresh(self):
         pass
 
 
@@ -196,6 +203,6 @@ class RelayingConnection(Connection):
     def state(self):
         return self.parent.state
 
-    def update_state(self):
-        self.parent.update_state()
+    def refresh(self):
+        self.parent.refresh()
 
