@@ -3,7 +3,7 @@
 <context>
     <name>Browser</name>
     <message>
-        <location filename="../browser.py" line="119"/>
+        <location filename="../browser.py" line="141"/>
         <source>Details</source>
         <translation>Szczegóły</translation>
     </message>
@@ -96,112 +96,112 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="52"/>
+        <location filename="../formatter.py" line="53"/>
         <source>Title:</source>
         <translation>Tytuł:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="52"/>
+        <location filename="../formatter.py" line="53"/>
         <source>%title%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="53"/>
+        <location filename="../formatter.py" line="54"/>
         <source>Artist:</source>
         <translation>Artysta:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="53"/>
+        <location filename="../formatter.py" line="54"/>
         <source>%artist%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="54"/>
+        <location filename="../formatter.py" line="55"/>
         <source>Album:</source>
         <translation>Album:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="54"/>
+        <location filename="../formatter.py" line="55"/>
         <source>%album%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="55"/>
+        <location filename="../formatter.py" line="56"/>
         <source>Date:</source>
         <translation>Data:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="55"/>
+        <location filename="../formatter.py" line="56"/>
         <source>%date%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="56"/>
+        <location filename="../formatter.py" line="57"/>
         <source>Track:</source>
         <translation>Ścieżka:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="56"/>
+        <location filename="../formatter.py" line="57"/>
         <source>%track%$if(%totaltracks%, / %totaltracks%,)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="57"/>
+        <location filename="../formatter.py" line="58"/>
         <source>Disc:</source>
         <translation>Dysk:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="57"/>
+        <location filename="../formatter.py" line="58"/>
         <source>%disc%$if(%totaldiscs%, / %totaldiscs%,)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="58"/>
+        <location filename="../formatter.py" line="59"/>
         <source>Comment:</source>
         <translation>Komentarz:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="58"/>
+        <location filename="../formatter.py" line="59"/>
         <source>%comment%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="59"/>
+        <location filename="../formatter.py" line="60"/>
         <source>Length:</source>
         <translation>Czas:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="59"/>
+        <location filename="../formatter.py" line="60"/>
         <source>$if(%length%,$time(%length%),)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="60"/>
+        <location filename="../formatter.py" line="61"/>
         <source>Last modified:</source>
         <translation>Ostatnio zmodyfikowany:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="60"/>
+        <location filename="../formatter.py" line="61"/>
         <source>%lastmodified%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="61"/>
+        <location filename="../formatter.py" line="62"/>
         <source>Composer:</source>
         <translation>Kompozytor:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="61"/>
+        <location filename="../formatter.py" line="62"/>
         <source>%composer%</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="62"/>
+        <location filename="../formatter.py" line="63"/>
         <source>Performer:</source>
         <translation>Wykonawca:</translation>
     </message>
     <message>
-        <location filename="../formatter.py" line="62"/>
+        <location filename="../formatter.py" line="63"/>
         <source>%performer%</source>
         <translation type="unfinished"></translation>
     </message>
@@ -215,11 +215,21 @@
         <source>%mpdversion%</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../formatter.py" line="52"/>
+        <source>Name:</source>
+        <translation>Nazwa:</translation>
+    </message>
+    <message>
+        <location filename="../formatter.py" line="52"/>
+        <source>%name%</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Playlists</name>
     <message>
-        <location filename="../lists.py" line="370"/>
+        <location filename="../lists.py" line="395"/>
         <source>New playlist</source>
         <translation>Nowa lista</translation>
     </message>
@@ -227,56 +237,124 @@
 <context>
     <name>Qygmy</name>
     <message>
-        <location filename="../qygmy.py" line="255"/>
+        <location filename="../qygmy.py" line="272"/>
         <source>Error</source>
         <translation>Błąd</translation>
     </message>
     <message>
-        <location filename="../qygmy.py" line="247"/>
+        <location filename="../qygmy.py" line="264"/>
         <source>Save current playlist</source>
         <translation>Zapisz listę</translation>
     </message>
     <message>
-        <location filename="../qygmy.py" line="248"/>
+        <location filename="../qygmy.py" line="265"/>
         <source>Playlist name:</source>
         <translation>Nazwa listy:</translation>
     </message>
     <message>
-        <location filename="../qygmy.py" line="271"/>
+        <location filename="../qygmy.py" line="288"/>
         <source>About Qygmy</source>
         <translation>O Qygmy</translation>
     </message>
     <message>
-        <location filename="../qygmy.py" line="257"/>
+        <location filename="../qygmy.py" line="274"/>
         <source>Playlist with such name already exists. Do you want to replace it?</source>
         <translation>Lista o tej nazwie już istnieje. Zastąpić?</translation>
     </message>
     <message>
-        <location filename="../qygmy.py" line="277"/>
+        <location filename="../qygmy.py" line="294"/>
         <source>&lt;h2&gt;Qygmy&lt;/h2&gt;&lt;p&gt;version {version}&lt;/p&gt;&lt;p&gt;Simple MPD client written in Python and Qt/PySide.&lt;/p&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/tsufeki/qygmy&quot;&gt;https://github.com/tsufeki/qygmy&lt;/a&gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qygmy&lt;/h2&gt;&lt;p&gt;wersja {version}&lt;/p&gt;&lt;p&gt;Prosty klient MPD napisany w Pythonie i Qt/PySide.&lt;/p&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/tsufeki/qygmy&quot;&gt;https://github.com/tsufeki/qygmy&lt;/a&gt;&lt;/p&gt;</translation>
     </message>
 </context>
+<context>
+    <name>SearchTags</name>
+    <message>
+        <location filename="../lists.py" line="495"/>
+        <source>Title</source>
+        <translation>Tytuł</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="496"/>
+        <source>Artist</source>
+        <translation>Artysta</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="497"/>
+        <source>Album</source>
+        <translation>Album</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="498"/>
+        <source>Genre</source>
+        <translation>Gatunek</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="499"/>
+        <source>Comment</source>
+        <translation>Komentarz</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="500"/>
+        <source>Composer</source>
+        <translation>Kompozytor</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="501"/>
+        <source>Performer</source>
+        <translation>Wykonawca</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="502"/>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="503"/>
+        <source>Track</source>
+        <translation>Ścieżka</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="504"/>
+        <source>Disc</source>
+        <translation>Dysk</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="508"/>
+        <source>Any</source>
+        <translation>Wszystko</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="509"/>
+        <source>File name</source>
+        <translation>Nazwa pliku</translation>
+    </message>
+    <message>
+        <location filename="../lists.py" line="505"/>
+        <source>Name</source>
+        <translation>Nazwa</translation>
+    </message>
+</context>
 <context>
     <name>Settings</name>
     <message>
-        <location filename="../dialogs.py" line="74"/>
+        <location filename="../dialogs.py" line="126"/>
         <source>Qygmy$if(%playing%, / $if(%artist%,%artist% u2014 )$if2(%title%,%filename%))</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dialogs.py" line="83"/>
+        <location filename="../dialogs.py" line="135"/>
         <source>$if3(%playing%%paused%,$time(%elapsed%)$if($and(%total%,$gt(%total%,0)), / $time(%total%)),%stopped%,Stopped,%connected%,Connected,Disconnected)</source>
         <translation>$if3(%playing%%paused%,$time(%elapsed%)$if($and(%total%,$gt(%total%,0)), / $time(%total%)),%stopped%,Zatrzymany,%connected%,Połączony,Rozłączony)</translation>
     </message>
     <message>
-        <location filename="../dialogs.py" line="88"/>
-        <source>&lt;span style=&quot;font-size: large; font-weight: bold&quot;&gt;$if2(%title%,%filename%)&lt;/span&gt;&lt;br&gt;%artist%$if(%album%, u2014 %album%)</source>
+        <location filename="../dialogs.py" line="141"/>
+        <source>$if(%name%,[%name%] )&lt;span style=&quot;font-size: large; font-weight: bold&quot;&gt;$if2(%title%,%filename%)&lt;/span&gt;&lt;br&gt;%artist%$if(%album%, u2014 %album%)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dialogs.py" line="92"/>
-        <source>$if(%artist%,%artist% u2014 )$if2(%title%,%filename%)</source>
+        <location filename="../dialogs.py" line="146"/>
+        <source>$if(%name%,[%name%] )$if(%artist%,%artist% u2014 )$if2(%title%,%filename%)</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -291,140 +369,135 @@
 <context>
     <name>browser</name>
     <message>
-        <location filename="../ui/browser.py" line="238"/>
+        <location filename="../ui/browser.py" line="249"/>
         <source>Music database</source>
         <translation>Baza muzyki</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="239"/>
+        <location filename="../ui/browser.py" line="250"/>
         <source>&amp;Database</source>
         <translation>&amp;Baza</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="240"/>
+        <location filename="../ui/browser.py" line="251"/>
         <source>&amp;Playlists</source>
         <translation>&amp;Listy</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="241"/>
+        <location filename="../ui/browser.py" line="252"/>
         <source>Tag to search</source>
         <translation>Szukany tag</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="242"/>
-        <source>Any</source>
-        <translation>Wszystko</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="243"/>
-        <source>Title</source>
-        <translation>Tytuł</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="244"/>
-        <source>Artist</source>
-        <translation>Artysta</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="245"/>
-        <source>Album</source>
-        <translation>Album</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="246"/>
-        <source>Comment</source>
-        <translation>Komentarz</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="247"/>
-        <source>File name</source>
-        <translation>Nazwa pliku</translation>
-    </message>
-    <message>
-        <location filename="../ui/browser.py" line="248"/>
+        <location filename="../ui/browser.py" line="253"/>
         <source>&amp;Search</source>
         <translation>&amp;Szukaj</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="249"/>
+        <location filename="../ui/browser.py" line="254"/>
         <source>&amp;Add selected</source>
         <translation>&amp;Dodaj zaznaczone</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="250"/>
+        <location filename="../ui/browser.py" line="255"/>
         <source>Add selected songs to the current playlist</source>
         <translation>Dodaj zaznaczone utwory do głównej listy</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="251"/>
+        <location filename="../ui/browser.py" line="256"/>
         <source>&amp;Close</source>
         <translation>&amp;Zamknij</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="252"/>
+        <location filename="../ui/browser.py" line="257"/>
         <source>Close this window</source>
         <translation>Zamknij to okno</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="253"/>
+        <location filename="../ui/browser.py" line="258"/>
         <source>Ctrl+W</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="254"/>
+        <location filename="../ui/browser.py" line="259"/>
         <source>Search</source>
         <translation>Szukaj</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="255"/>
+        <location filename="../ui/browser.py" line="260"/>
         <source>&amp;Remove selected</source>
         <translation>&amp;Usuń zaznaczone</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="256"/>
+        <location filename="../ui/browser.py" line="261"/>
         <source>Del</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="257"/>
+        <location filename="../ui/browser.py" line="262"/>
         <source>Add selected and &amp;play</source>
         <translation>Dodaj zaznaczone i &amp;odtwarzaj</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="258"/>
+        <location filename="../ui/browser.py" line="263"/>
         <source>Shift+Return</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="259"/>
+        <location filename="../ui/browser.py" line="264"/>
         <source>Song &amp;details...</source>
         <translation>&amp;Szczegóły...</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="260"/>
+        <location filename="../ui/browser.py" line="265"/>
         <source>Ctrl+I</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="261"/>
+        <location filename="../ui/browser.py" line="266"/>
         <source>Re&amp;name</source>
         <translation>Zmień &amp;nazwę</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="262"/>
+        <location filename="../ui/browser.py" line="267"/>
         <source>F2</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="263"/>
+        <location filename="../ui/browser.py" line="268"/>
         <source>R&amp;eplace the current playlist</source>
         <translation>Za&amp;stąp główną listę</translation>
     </message>
     <message>
-        <location filename="../ui/browser.py" line="264"/>
+        <location filename="../ui/browser.py" line="269"/>
         <source>Rep&amp;lace and play</source>
         <translation>Zas&amp;tąp i odtwarzaj</translation>
     </message>
+    <message>
+        <location filename="../ui/browser.py" line="270"/>
+        <source>C&amp;opy selected</source>
+        <translation>&amp;Kopiuj zaznaczone</translation>
+    </message>
+    <message>
+        <location filename="../ui/browser.py" line="271"/>
+        <source>Add with &amp;high priority</source>
+        <translation>Dodaj z &amp;wysokim priorytetem</translation>
+    </message>
+    <message>
+        <location filename="../ui/browser.py" line="272"/>
+        <source>Update the data&amp;base</source>
+        <translation>Odśwież &amp;bazę</translation>
+    </message>
+    <message>
+        <location filename="../ui/browser.py" line="273"/>
+        <source>Add &amp;URL...</source>
+        <translation>Dodaj U&amp;RL...</translation>
+    </message>
+    <message>
+        <location filename="../ui/browser.py" line="274"/>
+        <source>Ctrl+U</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>infodialog</name>
@@ -434,283 +507,316 @@
         <translation>Szczegóły</translation>
     </message>
 </context>
+<context>
+    <name>input_url</name>
+    <message>
+        <location filename="../dialogs.py" line="42"/>
+        <source>Add URL</source>
+        <translation>Dodaj URL</translation>
+    </message>
+    <message>
+        <location filename="../dialogs.py" line="43"/>
+        <source>URL:</source>
+        <translation>URL:</translation>
+    </message>
+</context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../ui/main.py" line="327"/>
+        <location filename="../ui/main.py" line="340"/>
         <source>&amp;Playback</source>
         <translation>&amp;Odtwarzanie</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="328"/>
+        <location filename="../ui/main.py" line="341"/>
         <source>&amp;Volume</source>
         <translation>&amp;Głośność</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="329"/>
+        <location filename="../ui/main.py" line="343"/>
         <source>Pla&amp;ylist</source>
         <translation>&amp;Lista</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="330"/>
+        <location filename="../ui/main.py" line="344"/>
         <source>P&amp;revious</source>
         <translation>Pop&amp;rzedni</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="331"/>
+        <location filename="../ui/main.py" line="345"/>
         <source>Previous song</source>
         <translation>Poprzedni utwór</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="332"/>
+        <location filename="../ui/main.py" line="346"/>
         <source>Ctrl+P</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="333"/>
+        <location filename="../ui/main.py" line="347"/>
         <source>&amp;Play</source>
         <translation>&amp;Odtwarzaj</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="361"/>
+        <location filename="../ui/main.py" line="375"/>
         <source>Space</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="335"/>
+        <location filename="../ui/main.py" line="349"/>
         <source>&amp;Stop</source>
         <translation>&amp;Zatrzymaj</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="336"/>
+        <location filename="../ui/main.py" line="350"/>
         <source>Ctrl+S</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="337"/>
+        <location filename="../ui/main.py" line="351"/>
         <source>&amp;Next</source>
         <translation>&amp;Następny</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="338"/>
+        <location filename="../ui/main.py" line="352"/>
         <source>Next Song</source>
         <translation>Następny utwór</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="339"/>
+        <location filename="../ui/main.py" line="353"/>
         <source>Ctrl+N</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="340"/>
+        <location filename="../ui/main.py" line="354"/>
         <source>&amp;Add...</source>
         <translation>&amp;Dodaj...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="341"/>
+        <location filename="../ui/main.py" line="355"/>
         <source>Add to playlist...</source>
         <translation>Dodaj do listy...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="342"/>
+        <location filename="../ui/main.py" line="356"/>
         <source>Ctrl+L</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="343"/>
+        <location filename="../ui/main.py" line="357"/>
         <source>&amp;Remove</source>
         <translation>&amp;Usuń</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="344"/>
+        <location filename="../ui/main.py" line="358"/>
         <source>Remove selected</source>
         <translation>Usuń zaznaczone</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="345"/>
+        <location filename="../ui/main.py" line="359"/>
         <source>Del</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="346"/>
+        <location filename="../ui/main.py" line="360"/>
         <source>R&amp;epeat</source>
         <translation>Po&amp;wtarzaj</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="347"/>
+        <location filename="../ui/main.py" line="361"/>
         <source>S&amp;huffle</source>
         <translation>&amp;Losowo</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="348"/>
+        <location filename="../ui/main.py" line="362"/>
         <source>&amp;Settings...</source>
         <translation>&amp;Ustawienia...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="349"/>
+        <location filename="../ui/main.py" line="363"/>
         <source>Ctrl+O</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="350"/>
+        <location filename="../ui/main.py" line="364"/>
         <source>Volume</source>
         <translation>Głośność</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="351"/>
+        <location filename="../ui/main.py" line="365"/>
         <source>&amp;Clear</source>
         <translation>&amp;Opróżnij</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="352"/>
+        <location filename="../ui/main.py" line="366"/>
         <source>Clear playlist</source>
         <translation>Opróżnij listę</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="353"/>
+        <location filename="../ui/main.py" line="367"/>
         <source>Dis&amp;connect from MPD</source>
         <translation>Rozłą&amp;cz z MPD</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="354"/>
+        <location filename="../ui/main.py" line="368"/>
         <source>&amp;Connect to MPD</source>
         <translation>Połą&amp;cz z MPD</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="355"/>
+        <location filename="../ui/main.py" line="369"/>
         <source>&amp;Update the database</source>
         <translation>Odśwież &amp;bazę</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="356"/>
+        <location filename="../ui/main.py" line="370"/>
         <source>S&amp;ingle track mode</source>
         <translation>&amp;Tryb pojedynczego utworu</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="357"/>
+        <location filename="../ui/main.py" line="371"/>
         <source>Single</source>
         <translation>Pojedyn.</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="358"/>
+        <location filename="../ui/main.py" line="372"/>
         <source>Re&amp;move songs after playback</source>
         <translation>U&amp;suń po odtworzeniu</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="359"/>
+        <location filename="../ui/main.py" line="373"/>
         <source>Consume</source>
         <translation>Usuń po</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="360"/>
+        <location filename="../ui/main.py" line="374"/>
         <source>&amp;Pause</source>
         <translation>P&amp;auzuj</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="362"/>
+        <location filename="../ui/main.py" line="376"/>
         <source>&amp;Save...</source>
         <translation>&amp;Zapisz</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="363"/>
+        <location filename="../ui/main.py" line="377"/>
         <source>Ctrl+T</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="364"/>
+        <location filename="../ui/main.py" line="378"/>
         <source>Song &amp;details...</source>
         <translation>&amp;Szczegóły</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="365"/>
+        <location filename="../ui/main.py" line="379"/>
         <source>Ctrl+I</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="366"/>
+        <location filename="../ui/main.py" line="380"/>
         <source>&amp;Quit</source>
         <translation>&amp;Wyjście</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="367"/>
+        <location filename="../ui/main.py" line="381"/>
         <source>Ctrl+Q</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="368"/>
+        <location filename="../ui/main.py" line="382"/>
         <source>Randomi&amp;ze</source>
         <translation>&amp;Wymieszaj</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="369"/>
+        <location filename="../ui/main.py" line="383"/>
         <source>&amp;MPD statistics...</source>
         <translation>Statystyki &amp;MPD...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="370"/>
+        <location filename="../ui/main.py" line="384"/>
         <source>&amp;High priority</source>
         <translation>Wysoki &amp;priorytet</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="371"/>
+        <location filename="../ui/main.py" line="385"/>
         <source>Set high priority for selected songs</source>
         <translation>Odtwórz zaznaczone z wyższym priorytetem</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="372"/>
+        <location filename="../ui/main.py" line="386"/>
         <source>Ctrl+H</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="373"/>
+        <location filename="../ui/main.py" line="387"/>
         <source>&amp;Normal priority</source>
         <translation>&amp;Normalny priorytet</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="374"/>
+        <location filename="../ui/main.py" line="388"/>
         <source>Set normal priority for selected songs</source>
         <translation>Odtwórz zaznaczone ze zwykłym priorytetem</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="375"/>
+        <location filename="../ui/main.py" line="389"/>
         <source>Ctrl+J</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="376"/>
+        <location filename="../ui/main.py" line="390"/>
         <source>&amp;Louder</source>
         <translation>&amp;Głośniej</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="377"/>
+        <location filename="../ui/main.py" line="391"/>
         <source>Ctrl+E</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="378"/>
+        <location filename="../ui/main.py" line="392"/>
         <source>&amp;Quieter</source>
         <translation>&amp;Ciszej</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="379"/>
+        <location filename="../ui/main.py" line="393"/>
         <source>Ctrl+D</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="380"/>
+        <location filename="../ui/main.py" line="394"/>
         <source>&amp;About Qygmy...</source>
         <translation>O &amp;Qygmy...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="381"/>
+        <location filename="../ui/main.py" line="395"/>
         <source>About Qt...</source>
         <translation>O Qt...</translation>
     </message>
     <message>
-        <location filename="../ui/main.py" line="382"/>
+        <location filename="../ui/main.py" line="396"/>
         <source>Re&amp;verse</source>
         <translation>Odw&amp;róć</translation>
     </message>
+    <message>
+        <location filename="../ui/main.py" line="397"/>
+        <source>C&amp;opy selected</source>
+        <translation>&amp;Kopiuj zaznaczone</translation>
+    </message>
+    <message>
+        <location filename="../ui/main.py" line="342"/>
+        <source>Audio &amp;outputs</source>
+        <translation>Wyjścia &amp;audio</translation>
+    </message>
+    <message>
+        <location filename="../ui/main.py" line="398"/>
+        <source>Add &amp;URL...</source>
+        <translation>Dodaj UR&amp;L...</translation>
+    </message>
+    <message>
+        <location filename="../ui/main.py" line="399"/>
+        <source>Ctrl+U</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>settings</name>
@@ -793,17 +899,17 @@
 <context>
     <name>templates</name>
     <message>
-        <location filename="../templates/template.py" line="150"/>
+        <location filename="../templates/template.py" line="154"/>
         <source>{}{}d {:02d}:{:02d}:{:02d}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../templates/template.py" line="151"/>
+        <location filename="../templates/template.py" line="155"/>
         <source>{}{}:{:02d}:{:02d}</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../templates/template.py" line="152"/>
+        <location filename="../templates/template.py" line="156"/>
         <source>{}{:02d}:{:02d}</source>
         <translation type="unfinished"></translation>
     </message>
